
function createFavoriteToolbar() {

  // Action to toggle the coordinate units in the bottom of the camera/drawing view
  var toggleCoordinatesAction = {
    id: "com.toonboom.toggleMouseCoordinateDisplay",
    text: "Toggle Mouse Coordinates Display Settings",
    icon: "earth.png",
    checkable: true,
    isEnabled: true,
    isChecked: preferences.getBool("DRAWING_VIEW_SHOW_RAW_MOUSE_COORDINATES", false), // initial state
    onPreferenceChanged: function () {
      // If the preference is changed from elsewhere, this will react and update the current state of the action
      this.isChecked = preferences.getBool("DRAWING_VIEW_SHOW_RAW_MOUSE_COORDINATES", false);
    },
    onTrigger: function () {
      // This is called when the user presses the button
      this.isChecked = !this.isChecked;
      preferences.setBool("DRAWING_VIEW_SHOW_RAW_MOUSE_COORDINATES", this.isChecked);
    }
  };
  ScriptManager.addAction(toggleCoordinatesAction);

  // Toggler to show particles as dots. Please not that 
  // the views must be refreshed when this preference changes
  var toggleShowParticlesAsDotAction = {
    id: "com.toonboom.ParticleShowParticlesAsDotsInOpenGL",
    text: "Toggle Show Particles as Dots",
    icon: "dots.png",
    checkable: true,
    isEnabled: true,
    isChecked: preferences.getBool("ParticleShowParticlesAsDotsInOpenGL", false),
    onPreferenceChanged: function () {
      this.isChecked = preferences.getBool("ParticleShowParticlesAsDotsInOpenGL", false);
    },
    onTrigger: function () {
      this.isChecked = !this.isChecked;
      preferences.setBool("ParticleShowParticlesAsDotsInOpenGL", this.isChecked);
      // here we call refresh views because we want to see the result immediately and not wait the next time the
      // windows are invalidated
      view.refreshViews();
    }
  };
  ScriptManager.addAction(toggleShowParticlesAsDotAction);

  // The actions associated to the tool switching do not need to
  // use the ScriptManager.addAction method. There are built in actions
  // that can be triggered for them.
  
  // Now, create the toolbar and add the buttons
  
    var favoriteToolbar = new ScriptToolbarDef({
      id: "com.toonboom.favoriteToolbar",
      text: "Favorites",
      customizable: true
    });

    favoriteToolbar.addButton({
      text: toggleCoordinatesAction.text,
      icon: toggleCoordinatesAction.icon,
      checkable: toggleCoordinatesAction.checkable,
      action: toggleCoordinatesAction.id
    });

    favoriteToolbar.addButton({
      text: toggleShowParticlesAsDotAction.text,
      icon: toggleShowParticlesAsDotAction.icon,
      checkable: toggleShowParticlesAsDotAction.checkable,
      action: toggleShowParticlesAsDotAction.id
    });
     
     favoriteToolbar.addButton({
        text: "Transform Tool",
        icon: "cameratoolbar/transformtool.svg", // This icon is part of the Harmony resources, we can use it
        checkable: true,
        responder: "scriptResponder",
        slot: "onActionActivateToolByName(QString)",
        itemParameter: "Transform"
    });

    favoriteToolbar.addButton({
        text: "Select Tool",
        icon: "drawingtool/select.svg",
        checkable: true,
        responder: "scriptResponder",
        slot: "onActionActivateToolByName(QString)",
        itemParameter: "Select"
    });

     favoriteToolbar.addButton({
        text: "Rotate Tool",
        icon: "cameratoolbar/rotatetool.svg",
        checkable: true,
        responder: "scriptResponder",
        slot: "onActionActivateToolByName(QString)",
        itemParameter: "Rotate"
    });

     favoriteToolbar.addButton({
        text: "Brush Tool",
        icon: "drawingtool/brush.svg",
        checkable: true,
        responder: "scriptResponder",
        slot: "onActionActivateToolByName(QString)",
        itemParameter: "Brush"
    });
    
    // Add the toolbar to the toolbar system   
    ScriptManager.addToolbar(favoriteToolbar); 
         
}



function configure(packageFolder, packageName) {
  MessageLog.trace("Creating Favorite Toolbar");
  createFavoriteToolbar();
}

exports.configure = configure;



